@@ -1,14 +1,14 @@
 var RemoteAutocompleteWidget = {
     /*
     The default deck getValue() implementation just returns the PK from the
-    result HTML. RemoteAutocompleteWidget's implementation checks for a textarea
-    that would contain a JSON dict in the result's HTML. If the dict has a
+    choice HTML. RemoteAutocompleteWidget's implementation checks for a textarea
+    that would contain a JSON dict in the choice's HTML. If the dict has a
     'value' key, then return this value. Otherwise, make a blocking ajax
     request: POST the json dict to the autocomplete url. It expects that the
     response will contain the value.
     */
-    getValue: function(result) {
-        var value = result.data('value');
+    getValue: function(choice) {
+        var value = choice.data('value');
 
         if (typeof(value)=='string' && isNaN(value) && value.match(/^http:/)) {
             $.ajax(this.autocompleteOptions.url, {
@@ -21,6 +21,8 @@ var RemoteAutocompleteWidget = {
                     value = text;
                 }
             });
+
+            choice.data('value', value);
         }
 
         return value;
